@@ -68,6 +68,9 @@ typedef enum {
 #if (!PK_CHECK_VERSION(0,9,1))
 #define PK_ROLE_ENUM_DEPENDS_ON				(PK_ROLE_ENUM_GET_DEPENDS)
 #define PK_ROLE_ENUM_REQUIRED_BY			(PK_ROLE_ENUM_GET_REQUIRES)
+#define PK_ROLE_ENUM_GET_DETAILS_LOCAL			(PK_ROLE_ENUM_REPAIR_SYSTEM+1)
+#define PK_ROLE_ENUM_GET_FILES_LOCAL			(PK_ROLE_ENUM_GET_DETAILS_LOCAL+1)
+#define PK_ROLE_ENUM_REPO_REMOVE			(PK_ROLE_ENUM_GET_FILES_LOCAL+1)
 #endif
 
 const gchar	*gpk_role_enum_to_localised_past	(PkRoleEnum	 role)
